.. _tutorials-and-presentations:

Tutorials and Presentations
===========================

Tutorials
---------

.. toctree::
    :maxdepth: 1
    :hidden:

    demo

.. grid:: 1 2 2 2
    :gutter: 2


    .. grid-item-card::
       :text-align: center
       :link: demo.html

       .. image:: https://xbatcher.readthedocs.io/en/latest/_images/demo_4_0.png
           :alt: Xbatcher demonstration
       +++
       Xbatcher demonstration

Presentations
-------------

.. card:: Xbatcher - A Python Package That Simplifies Feeding Xarray Data Objects to Machine Learning Libraries

    2023 AMS Annual Meeting
    ^^^


    | Presentation Recording (starts at 45:30): `AMS Confex <https://ams.confex.com/recording/ams/103ANNUAL/mp4/CGNTFL54WCL/67cfb841cba94216ff99f1eb15286ba2/session63444_5.mp4>`_
    | DOI: `10.6084/m9.figshare.22264072.v1 <https://doi.org/10.6084/m9.figshare.22264072.v1>`_

    +++
    Max Jones, Joe Hamman, and Wei Ji Leong
